<!DOCTYPE html>
{%- set url_root = pathto('', 1) %}
{# XXX necessary? #}
{%- if url_root == '#' %}{% set url_root = '' %}{% endif %}

{%- macro script() %}
    <script type="text/javascript">
      var DOCUMENTATION_OPTIONS = {
        URL_ROOT:    '{{ url_root }}',
        VERSION:     '{{ release|e }}',
        COLLAPSE_INDEX: false,
        FILE_SUFFIX: '{{ '' if no_search_suffix else file_suffix }}',
        HAS_SOURCE:  {{ has_source|lower }},
        SOURCELINK_SUFFIX:  '{{ sourcelink_suffix }}'
      };
    </script>
    {%- for scriptfile in script_files %}
    <script type="text/javascript" src="{{ pathto(scriptfile, 1) }}"></script>
    {%- endfor %}
{%- endmacro %}

{%- macro css() %}
    <!--link rel="stylesheet" href="{{ pathto('_static/' + style, 1) }}" type="text/css" /-->
    <link rel="stylesheet" href="{{ pathto('_static/pygments.css', 1) }}" type="text/css" />
    <link rel="stylesheet" href="{{ pathto('_static/css/site.css', 1) }}"/>
    {%- for cssfile in css_files %}
    <link rel="stylesheet" href="{{ pathto(cssfile, 1) }}" type="text/css" />
    {%- endfor %}
{%- endmacro %}

<html>
  <head>
    <meta charset="utf-8">
    {{ metatags }}
    {%- block htmltitle %}
    <title>{{ title|striptags|e }}</title>
    {%- endblock %}
    {{ css() }}
    {%- if not embedded %}
    {{ script() }}
    {%- if use_opensearch %}
    <link rel="search" type="application/opensearchdescription+xml"
          title="{% trans docstitle=docstitle|e %}Search within {{ docstitle }}{% endtrans %}"
          href="{{ pathto('_static/opensearch.xml', 1) }}"/>
    {%- endif %}
    {%- if favicon %}
    <link rel="shortcut icon" href="{{ pathto('_static/' + favicon, 1) }}"/>
    {%- endif %}
    {%- endif %}
{%- block linktags %}
    {%- if hasdoc('about') %}
    <link rel="author" title="{{ _('About these documents') }}" href="{{ pathto('about') }}" />
    {%- endif %}
    {%- if hasdoc('genindex') %}
    <link rel="index" title="{{ _('Index') }}" href="{{ pathto('genindex') }}" />
    {%- endif %}
    {%- if hasdoc('search') %}
    <link rel="search" title="{{ _('Search') }}" href="{{ pathto('search') }}" />
    {%- endif %}
    {%- if hasdoc('copyright') %}
    <link rel="copyright" title="{{ _('Copyright') }}" href="{{ pathto('copyright') }}" />
    {%- endif %}
    <link rel="top" title="{{ docstitle|e }}" href="{{ pathto('index') }}" />
    {%- if parents %}
    <link rel="up" title="{{ parents[-1].title|striptags|e }}" href="{{ parents[-1].link|e }}" />
    {%- endif %}
    {%- if next %}
    <link rel="next" title="{{ next.title|striptags|e }}" href="{{ next.link|e }}" />
    {%- endif %}
    {%- if prev %}
    <link rel="prev" title="{{ prev.title|striptags|e }}" href="{{ prev.link|e }}" />
    {%- endif %}
{%- endblock %}
{%- block extrahead %} {% endblock %}
</head>
<body>
    <div class="wrapper">
        <div class="header">
            <header>
                <img class="logo" src="{{ pathto('_static/isso.svg', 1) }}" alt="Wynaut by @veekun"/>
                <div class="title">
                    <a href="{{ pathto(".") }}">
                        <h1>Isso</h1>
                        <h2>a commenting server similar to Disqus</h2>
                    </a>
                </div>
            </header>
            <nav>
                <ul>
                    <li><a href="{{ pathto('faq') }}">FAQ</a></li>
                    <li><a href="{{ pathto('contribute') }}">Contribute</a></li>
                    <li><a href="{{ pathto('docs') }}">Documentation</a></li>
                </ul>
            </nav>
        </div>

        <div class="outer">
            {% block header %} {% endblock %}
        </div>


        <main>
        {% block body %} {% endblock %}
        </main>

        <div class="push"></div>
    </div>

    <div class="outer footer">
        {%- block footer %}
        <footer>
        &copy; Copyright {{ copyright }}.

        {%- if last_updated %}
            Last updated on {{ last_updated }}.
        {%- endif %}

        Made with <a href="http://sphinx-doc.org/">Sphinx</a>.
        </footer>
    </div>

{%- endblock %}
  </body>
</html>
