define({
    "postbox-text": "Tutaj wpisz komentarz (co najmniej 3 znaki)",
    "postbox-author": "Imię/nick (opcjonalnie)",
    "postbox-email": "E-mail (opcjonalnie)",
    "postbox-website": "Strona (opcjonalnie)",
    "postbox-preview": "Visualizar",
    "postbox-edit": "Edytuj",
    "postbox-submit": "Wyślij",
    "num-comments": "Jeden komentarz\n{{ n }} komentarzy",
    "no-comments": "Jeszcze nie ma komentarzy",
    "comment-reply": "Odpowiedz",
    "comment-edit": "Edytuj",
    "comment-save": "Zapisz",
    "comment-delete": "Usuń",
    "comment-confirm": "Potwierdź",
    "comment-close": "Zamknij",
    "comment-cancel": "Anuluj",
    "comment-deleted": "Komentarz usunięty.",
    "comment-queued": "Komentarz w kolejce do moderacji",
    "comment-anonymous": "Anonim",
    "comment-hidden": "{{ n }} ukrytych",
    "date-now": "teraz",
    "date-minute": "minutę temu\n{{ n }} minut temu",
    "date-hour": "godzinę temu\n{{ n }} godzin temu",
    "date-day": "wczoraj\n{{ n }} dni temu",
    "date-week": "w ubiegłym tygodniu\n{{ n }} tygodni temu",
    "date-month": "w ubiegłym miesiącu\n{{ n }} miesięcy temu",
    "date-year": "w ubiegłym roku\n{{ n }} lat temu"
});
